@@ -494,7 +494,7 @@ polybezier_bbox(const BezPoint *pts, int numpoints,
        account with the "pointy corners" X (and PS) add when LINEJOIN_MITER mode is 
        in force. */
 
-    if ((!start) && (!end)) { /* We have a non-extremity vertex. */
+    if (!end) { /* only the last segment might not produce overshoot. */
       Point vpx,vxn;
       real co,alpha;
 
@@ -503,14 +503,19 @@ polybezier_bbox(const BezPoint *pts, int numpoints,
       point_copy_add_scaled(&vxn,&vn,&vx,-1);
       point_normalize(&vxn);
 
-      co = point_dot(&vpx,&vxn);      
-      alpha = acos(-co); 
+      co = point_dot(&vpx,&vxn);
+      if (co >= 1.0)
+        alpha = 0.0;
+      else if (co <= -1.0)
+        alpha = M_PI;
+      else
+        alpha = dia_acos(-co);
       if (co > -0.9816) { /* 0.9816 = cos(11deg) */
         /* we have a pointy join. */
         real overshoot;
         Point vovs,pto;
 
-	if (finite(alpha))
+	if (alpha > 0.0 && alpha < M_PI)
 	  overshoot = extra->middle_trans / sin(alpha/2.0);
 	else /* prependicular? */
 	  overshoot = extra->middle_trans;
